﻿// (c) Copyright Microsoft Corporation.
// This source is subject to [###LICENSE_NAME###].
// Please see [###LICENSE_LINK###] for details.
// All other rights reserved.

using System;
using System.Diagnostics.CodeAnalysis;
using System.Windows;
using System.Windows.Data;

[assembly: SuppressMessage("Compatibility", "SWC4000:GeneralWPFCompatibilityRule", MessageId = "HierarchicalDataTemplate.get_ItemsSource(), System.Windows.Data.Binding (Silverlight) vs System.Windows.Data.BindingBase (wpf)", Justification = "BindingBase isn't sufficiently rich enough for this purpose.  We use Binding instead, just like FrameworkElement.SetBinding.")]

namespace Microsoft.Silverlight.Testing.Controls
{
    /// <summary>
    /// Represents a <see cref="T:System.Windows.DataTemplate" /> that supports
    /// <see cref="T:Microsoft.Silverlight.Testing.Controls.HeaderedItemsControl" /> objects,
    /// such as <see cref="T:Microsoft.Silverlight.Testing.Controls.TreeViewItem" />.
    /// </summary>
    /// <QualityBand>Stable</QualityBand>
    public partial class HierarchicalDataTemplate : DataTemplate
    {
        /// <summary>
        /// Gets or sets the collection that is used to generate content for the
        /// next sublevel in the data hierarchy.
        /// </summary>
        /// <value>
        /// The collection that is used to generate content for the next
        /// sublevel in the data hierarchy.  The default value is null.
        /// </value>
        public Binding ItemsSource { get; set; }

        #region public DataTemplate ItemTemplate
        /// <summary>
        /// The DataTemplate to apply to the ItemTemplate property on a
        /// generated HeaderedItemsControl (such as a MenuItem or a
        /// TreeViewItem), to indicate how to display items from the next level
        /// in the data hierarchy.
        /// </summary>
        private DataTemplate _itemTemplate;

        /// <summary>
        /// Gets a value indicating whether the ItemTemplate property was set on
        /// the template.
        /// </summary>
        internal bool IsItemTemplateSet { get; private set; }

        /// <summary>
        /// Gets or sets the <see cref="T:System.Windows.DataTemplate" /> to
        /// apply to the
        /// <see cref="P:Microsoft.Silverlight.Testing.Controls.ItemsControl.ItemTemplate" />
        /// property on a generated
        /// <see cref="T:Microsoft.Silverlight.Testing.Controls.HeaderedItemsControl" />, such
        /// as a <see cref="T:Microsoft.Silverlight.Testing.Controls.TreeViewItem" />, to
        /// indicate how to display items from the next sublevel in the data
        /// hierarchy.
        /// </summary>
        /// <value>
        /// The <see cref="T:System.Windows.DataTemplate" /> to apply to the
        /// <see cref="P:Microsoft.Silverlight.Testing.Controls.ItemsControl.ItemTemplate" />
        /// property on a generated
        /// <see cref="T:Microsoft.Silverlight.Testing.Controls.HeaderedItemsControl" />, such
        /// as a <see cref="T:Microsoft.Silverlight.Testing.Controls.TreeViewItem" />, to
        /// indicate how to display items from the next sublevel in the data
        /// hierarchy.
        /// </value>
        public DataTemplate ItemTemplate
        {
            get { return _itemTemplate; }
            set
            {
                IsItemTemplateSet = true;
                _itemTemplate = value;
            }
        }
        #endregion public DataTemplate ItemTemplate

        #region public Style ItemContainerStyle
        /// <summary>
        /// The Style to apply to the ItemContainerStyle property on a generated
        /// HeaderedItemsControl (such as a MenuItem or a TreeViewItem), to
        /// indicate how to style items from the next level in the data
        /// hierarchy.
        /// </summary>
        private Style _itemContainerStyle;

        /// <summary>
        /// Gets a value indicating whether the ItemContainerStyle property was
        /// set on the template.
        /// </summary>
        internal bool IsItemContainerStyleSet { get; private set; }

        /// <summary>
        /// Gets or sets the <see cref="T:System.Windows.Style" /> that is
        /// applied to the item container for each child item.
        /// </summary>
        /// <value>
        /// The style that is applied to the item container for each child item.
        /// </value>
        public Style ItemContainerStyle
        {
            get { return _itemContainerStyle; }
            set
            {
                IsItemContainerStyleSet = true;
                _itemContainerStyle = value;
            }
        }
        #endregion public Style ItemContainerStyle

        /// <summary>
        /// Initializes a new instance of the
        /// <see cref="T:System.Windows.HierarchicalDataTemplate" /> class.
        /// </summary>
        public HierarchicalDataTemplate()
        {
        }
    }
}